package %PACKAGE%;

import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceCategory;

public class LiveWallpaperSettings extends PreferenceActivity
    implements SharedPreferences.OnSharedPreferenceChangeListener {
	
	private Preference mCounter_settings = null;
	
    @Override
    protected void onCreate(Bundle b) {
        super.onCreate(b);
        
        getPreferenceManager().setSharedPreferencesName(SBLiveWallpaper.SHARED_PREFS_NAME);
        
    	boolean isDemo = getBooleanResource("isDemo");
    	boolean mDisableInteraction = getBooleanResource("disableInteraction");
    	int mItemCount = getStringArrayResourceCount("screen_items");
    	
    	
    	addPreferencesFromResource(R.xml.lwp_settings);
    	
    	/*
        if (isDemo) addPreferencesFromResource(R.xml.lwp_settings_demo);
        else addPreferencesFromResource(R.xml.lwp_settings);
        */
        
        getPreferenceManager().getSharedPreferences().registerOnSharedPreferenceChangeListener(this);
        
        
        PreferenceCategory main_preference_category = (PreferenceCategory) findPreference("main_preference_category");
        
        // is interaction is disabled during build then we need to remove that options from preferences 
        if (mDisableInteraction || isDemo || mItemCount == 0) {        	
        	Preference disable_interaction = getPreferenceScreen().findPreference("disable_interaction");
        	main_preference_category.removePreference(disable_interaction);          
        }
        
        // remove hide items checkbox if there are no items by default
        if (mItemCount == 0 || isDemo || mItemCount == 0) {        	
        	main_preference_category.removePreference(getPreferenceScreen().findPreference("hide_items"));
        }
        
        if (isDemo || mItemCount == 0) {
        	// remove preference items        	
        	main_preference_category.removePreference(getPreferenceScreen().findPreference("speed_settings"));
        	main_preference_category.removePreference(getPreferenceScreen().findPreference("direction_settings"));
        	main_preference_category.removePreference(getPreferenceScreen().findPreference("counter_settings"));        	
        }
        
        if (!isDemo) {
        	main_preference_category.removePreference(getPreferenceScreen().findPreference("demo_tag"));        	
        }
        
        if (mDisableInteraction) {
        	main_preference_category.removePreference(getPreferenceScreen().findPreference("counter_settings")); 
        }
               
        
    }

    @Override
    protected void onResume() {
        super.onResume();
    }

    @Override
    protected void onDestroy() {
        getPreferenceManager().getSharedPreferences().unregisterOnSharedPreferenceChangeListener(this);
        super.onDestroy();
    }

    public void onSharedPreferenceChanged(SharedPreferences sharedPreferences, String key) {
    	
    	/*
    	boolean isDisabledInteraction = sharedPreferences.getBoolean("disable_interaction", false);
    	
    	PreferenceCategory main_preference_category = (PreferenceCategory) findPreference("main_preference_category");
    	
    	if (isDisabledInteraction) {
    		mCounter_settings = getPreferenceScreen().findPreference("counter_settings");
    		main_preference_category.removePreference(mCounter_settings);    	
    	}
    	else {
    		if (mCounter_settings != null) main_preference_category.addPreference(mCounter_settings);
    	}
    	*/
    }
    
    
    // helper methods
    public String getStringResource(String name) {    	
    	String str = ""; 
    	
    	try {
    		str = getResources().getString(getResources().getIdentifier(name, "string", getPackageName()));
    	}
    	catch(Exception ex) {    		
    	}    
    	
    	return str;
    }
    
    public boolean getBooleanResource(String name) {      	
    	boolean bl = false;
    	
    	try {
    		bl = getStringResource(name).equals("true") ? true : false;
    	}
    	catch(Exception ex) {}
    	
    	return bl;   	
    }

    public String[] getStringArrayResource(String name) {    	
    	String[] str = new String[0];
    	
    	try {
    		str = getResources().getStringArray(getResources().getIdentifier(name, "array", getPackageName()));
    	}
    	catch(Exception ex) {}
    	
    	return str;
	}
    
    public int getStringArrayResourceCount(String key) {    	
    	return getStringArrayResource(key).length;
    }
}
